Exception: Simulacrum::Browserstack::Runner::NoRemoteSessionsAvailable

Inherits:
RuntimeError
  • Object
show all
Defined in:
lib/simulacrum/browserstack/runner.rb

Overview

Exception to indicate that Browserstack has no available sessions to start a new test run, this is used inside a retries loop but will be raised if maximum retries is exceeded