Class: Simulacrum::Browserstack::Driver
- Inherits:
-
Driver
- Object
- Driver
- Simulacrum::Browserstack::Driver
- Defined in:
- lib/simulacrum/browserstack/driver.rb
Overview
Responsible for registering a custom Capybara driver for use with Selenium grid endpoints (Browserstack, SauceLabs, etc.). Configures selenium options via ENV vars so that they can be passed into